@@ -36,6 +36,7 @@ static gchar *contributors[] = {
 	"J\xc3\xa9r\xc3\xb4me Bolliet",
 	"Andreas Bolsch",
 	"Dave Bordoley",
+	"Karsten Br\xC3\xA4" "ckelmann",
 	"Dario Bressanini",
 	"Emmanuel Briot",
 	"Stephen Browne",
@@ -178,6 +179,7 @@ static gchar *contributors[] = {
 	"Raph Levien",
 	"Matt Loper",
 	"Nick Lopez",
+	"Ryan Lortie",
 	"Dirk Lutjens",
 	"Josh MacDonald",
 	"Davyd Madeley",
@@ -323,6 +325,7 @@ static gchar *contributors[] = {
 	"Vendu",
 	"Andrew Veliath",
 	"Luis Villa",
+	"Olav Vitters",
 	"Marius Vollmer",
 	"Shawn Wagner",
 	N_("Wanda The GNOME Fish"),
