@@ -135,13 +135,12 @@ canvas_button_press_event (GtkWidget      *widget,
 	if (event->y <= 80.0)
 		return FALSE;
 
-	if (contrib_i >= (G_N_ELEMENTS (contributors) - 1))
-		text = g_strdup_printf ("<b>%s</b>", _("The End!"));
-	else {
-		text = g_strdup_printf ("<b>%s</b>", 
-					contributors[contrib_order[contrib_i]]);
-		contrib_i++;
-	}
+	if (contrib_i >= G_N_ELEMENTS (contributors))
+		contrib_i = 0;
+
+	text = g_strdup_printf ("<b>%s</b>", 
+				contributors[contrib_order[contrib_i]]);
+	contrib_i++;
 
 	gnome_canvas_item_set (GNOME_CANVAS_ITEM (user_data),
 			       "markup", text,
@@ -161,12 +160,8 @@ display_contributors (gpointer data)
 	static GnomeCanvasItem *contributor_rect = NULL;
 	static GnomeCanvasItem *contributor_text = NULL;
 
-	if (contrib_i >= (G_N_ELEMENTS (contributors) - 1)) {
-		g_signal_handlers_disconnect_by_func (canvas,
-						      canvas_button_press_event,
-						      contributor_text);
-		return FALSE;
-	}
+	if (contrib_i >= G_N_ELEMENTS (contributors))
+		contrib_i = 0;
 
 	if (!contributor) {
 		gchar *text;
@@ -481,7 +476,7 @@ load_random_header (void)
 }
 
 static GdkPixbuf *
-load_button (void)
+load_logo (void)
 {
 	gchar *file;
 	GdkPixbuf *pixbuf;
@@ -489,10 +484,10 @@ load_button (void)
 
 	file = gnome_program_locate_file (NULL,
 					  GNOME_FILE_DOMAIN_DATADIR,
-					  "gnome-about/gnome-64.gif",
+					  "gnome-about/gnome-64.png",
 					  TRUE, NULL);
 	if (!file) {
-		show_error_dialog (_("Could not locate the GNOME logo button."));
+		show_error_dialog (_("Could not locate the GNOME logo."));
 
 		return NULL;
 	}
@@ -949,7 +944,7 @@ create_canvas (void)
 	GnomeCanvasPoints *points;
 
 	GdkPixbuf *header;
-	GdkPixbuf *button;
+	GdkPixbuf *logo;
 
 	gdouble current_x;
 	gdouble current_y;
@@ -984,14 +979,14 @@ create_canvas (void)
 				      "pixbuf", header,
 				      NULL);
 
-	/* load button logo in advance, we need it's size */
-	button = load_button ();
-	if (!button)
+	/* load logo in advance, we need it's size */
+	logo = load_logo ();
+	if (!logo)
 		/* emergency stop complete with leaks */
 		return NULL;
 
 	/* and a coulple o' links */
-	current_x = 10.0 + (gdouble)gdk_pixbuf_get_width (button) + 10.0;
+	current_x = 10.0 + (gdouble)gdk_pixbuf_get_width (logo) + 10.0;
 	current_y = (gdouble)gdk_pixbuf_get_height (header) + 5.0;
 
 	href = href_item_new (root,
@@ -1064,12 +1059,12 @@ create_canvas (void)
 
 	gnome_canvas_points_free (points);
 
-	/* the gnome button logo */
+	/* the gnome logo */
 	item = gnome_canvas_item_new (root,
 				      gnome_canvas_pixbuf_get_type (),
 				      "x", 10.0,
 				      "y", 10.0,
-				      "pixbuf", button,
+				      "pixbuf", logo,
 				      NULL);
 
 	/* and some introduction text */
@@ -1177,7 +1172,7 @@ create_about_dialog (void)
 }
 
 static void
-generate_randomness ()
+generate_randomness (void)
 {
 	gint i;
 	gint random_number;
